package model

import (
	"git.getensh.com/common/gopkgsv2/database"
	"gorm.io/gorm"
)

type SyStyleModel interface {
	Update(db *gorm.DB, values interface{}) error
	List(db *gorm.DB, pagination *Pagination, join bool) ([]StyleList, error)
	Count(db *gorm.DB, join bool) (int64, error)
	Get(db *gorm.DB) (*GdSyStyle, error)
	StyleList(db *gorm.DB, fields string, limit int) ([]GdSyStyle, error)
	StyleListByMap(db *gorm.DB, fields string, limit int) ([]map[string]interface{}, error)
}

type GdSyStyle struct {
	ID                                  int64  `gorm:"column:id"                                     json:"id"                                     form:"id"`
	Initial                             string `gorm:"column:initial"                                json:"initial"                                form:"initial"`
	BrandId                             string `gorm:"column:brand_id"                               json:"brand_id"                               form:"brand_id"`
	BrandName                           string `gorm:"column:brand_name"                             json:"brand_name"                             form:"brand_name"`
	SeriesId                            string `gorm:"column:series_id"                              json:"series_id"                              form:"series_id"`
	SeriesName                          string `gorm:"column:series_name"                            json:"series_name"                            form:"series_name"`
	StyleId                             string `gorm:"column:style_id"                               json:"style_id"                               form:"style_id"`
	StyleName                           string `gorm:"column:style_name"                             json:"style_name"                             form:"style_name"`
	Level                               string `gorm:"column:level"                                  json:"level"                                  form:"level"`
	Maker                               string `gorm:"column:maker"                                  json:"maker"                                  form:"maker"`
	MakerId                             string `gorm:"column:maker_id"                               json:"maker_id"                               form:"maker_id"`
	OnSale                              string `gorm:"column:on_sale"                                json:"on_sale"                                form:"on_sale"`
	ModelYear                           string `gorm:"column:model_year"                             json:"model_year"                             form:"model_year"`
	MarketTime                          string `gorm:"column:market_time"                            json:"market_time"                            form:"market_time"`
	PriceYuan                           string `gorm:"column:price_yuan"                             json:"price_yuan"                             form:"price_yuan"`
	Price                               string `gorm:"column:price"                                  json:"price"                                  form:"price"`
	SubLevel                            string `gorm:"column:sub_level"                              json:"sub_level"                              form:"sub_level"`
	FuelTypeDetail1                     string `gorm:"column:fuel_type_detail1"                      json:"fuel_type_detail1"                      form:"fuel_type_detail1"`
	EmissionStandard                    string `gorm:"column:emission_standard"                      json:"emission_standard"                      form:"emission_standard"`
	FastChargingTime                    string `gorm:"column:fast_charging_time"                     json:"fast_charging_time"                     form:"fast_charging_time"`
	SlowChargingTime                    string `gorm:"column:slow_charging_time"                     json:"slow_charging_time"                     form:"slow_charging_time"`
	FastChargeAmount                    string `gorm:"column:fast_charge_amount"                     json:"fast_charge_amount"                     form:"fast_charge_amount"`
	MaximumPower                        string `gorm:"column:maximum_power"                          json:"maximum_power"                          form:"maximum_power"`
	MaximumTorque                       string `gorm:"column:maximum_torque"                         json:"maximum_torque"                         form:"maximum_torque"`
	Engine                              string `gorm:"column:engine"                                 json:"engine"                                 form:"engine"`
	Alternator                          string `gorm:"column:alternator"                             json:"alternator"                             form:"alternator"`
	GearboxDesc                         string `gorm:"column:gearbox_desc"                           json:"gearbox_desc"                           form:"gearbox_desc"`
	Lwh                                 string `gorm:"column:lwh"                                    json:"lwh"                                    form:"lwh"`
	VehicleStructure                    string `gorm:"column:vehicle_structure"                      json:"vehicle_structure"                      form:"vehicle_structure"`
	MaximumSpeed                        string `gorm:"column:maximum_speed"                          json:"maximum_speed"                          form:"maximum_speed"`
	HundredAccelerate                   string `gorm:"column:hundred_accelerate"                     json:"hundred_accelerate"                     form:"hundred_accelerate"`
	HundredAccelerateMeasure            string `gorm:"column:hundred_accelerate_measure"             json:"hundred_accelerate_measure"             form:"hundred_accelerate_measure"`
	BrakingDistanceMeasure              string `gorm:"column:braking_distance_measure"               json:"braking_distance_measure"               form:"braking_distance_measure"`
	MaximumSimulationMilageMeasure      string `gorm:"column:maximum_simulation_milage_measure"      json:"maximum_simulation_milage_measure"      form:"maximum_simulation_milage_measure"`
	OilWearComrehensive                 string `gorm:"column:oil_wear_comrehensive"                  json:"oil_wear_comrehensive"                  form:"oil_wear_comrehensive"`
	OilWearMeasure                      string `gorm:"column:oil_wear_measure"                       json:"oil_wear_measure"                       form:"oil_wear_measure"`
	VehicleWarranty                     string `gorm:"column:vehicle_warranty"                       json:"vehicle_warranty"                       form:"vehicle_warranty"`
	Long                                string `gorm:"column:long"                                   json:"long"                                   form:"long"`
	Wide                                string `gorm:"column:wide"                                   json:"wide"                                   form:"wide"`
	High                                string `gorm:"column:high"                                   json:"high"                                   form:"high"`
	Wheelbase                           string `gorm:"column:wheelbase"                              json:"wheelbase"                              form:"wheelbase"`
	FrontWheelDistance                  string `gorm:"column:front_wheel_distance"                   json:"front_wheel_distance"                   form:"front_wheel_distance"`
	BackWheelDistance                   string `gorm:"column:back_wheel_distance"                    json:"back_wheel_distance"                    form:"back_wheel_distance"`
	MinimumGroundClearance              string `gorm:"column:minimum_ground_clearance"               json:"minimum_ground_clearance"               form:"minimum_ground_clearance"`
	DoorNumber                          string `gorm:"column:door_number"                            json:"door_number"                            form:"door_number"`
	SeatNumber                          string `gorm:"column:seat_number"                            json:"seat_number"                            form:"seat_number"`
	OilboxVolume                        string `gorm:"column:oilbox_volume"                          json:"oilbox_volume"                          form:"oilbox_volume"`
	TrunkVolume                         string `gorm:"column:trunk_volume"                           json:"trunk_volume"                           form:"trunk_volume"`
	UnladenMass                         string `gorm:"column:unladen_mass"                           json:"unladen_mass"                           form:"unladen_mass"`
	EngineType                          string `gorm:"column:engine_type"                            json:"engine_type"                            form:"engine_type"`
	Displacement                        string `gorm:"column:displacement"                           json:"displacement"                           form:"displacement"`
	DisplacementL                       string `gorm:"column:displacement_l"                         json:"displacement_l"                         form:"displacement_l"`
	AirIntakForm                        string `gorm:"column:air_intak_form"                         json:"air_intak_form"                         form:"air_intak_form"`
	AirIntakFormDetail                  string `gorm:"column:air_intak_form_detail"                  json:"air_intak_form_detail"                  form:"air_intak_form_detail"`
	CylinderArrangement                 string `gorm:"column:cylinder_arrangement"                   json:"cylinder_arrangement"                   form:"cylinder_arrangement"`
	CylinderNumber                      string `gorm:"column:cylinder_number"                        json:"cylinder_number"                        form:"cylinder_number"`
	CylinderValveNumber                 string `gorm:"column:cylinder_valve_number"                  json:"cylinder_valve_number"                  form:"cylinder_valve_number"`
	ReductionRatio                      string `gorm:"column:reduction_ratio"                        json:"reduction_ratio"                        form:"reduction_ratio"`
	ValveMechanism                      string `gorm:"column:valve_mechanism"                        json:"valve_mechanism"                        form:"valve_mechanism"`
	CylinderDiameter                    string `gorm:"column:cylinder_diameter"                      json:"cylinder_diameter"                      form:"cylinder_diameter"`
	PistonStroke                        string `gorm:"column:piston_stroke"                          json:"piston_stroke"                          form:"piston_stroke"`
	MaximumHorsepower                   string `gorm:"column:maximum_horsepower"                     json:"maximum_horsepower"                     form:"maximum_horsepower"`
	MaximumPowerRpm                     string `gorm:"column:maximum_power_rpm"                      json:"maximum_power_rpm"                      form:"maximum_power_rpm"`
	Rpm                                 string `gorm:"column:rpm"                                    json:"rpm"                                    form:"rpm"`
	EngineTechnology                    string `gorm:"column:engine_technology"                      json:"engine_technology"                      form:"engine_technology"`
	FuelTypeDetail                      string `gorm:"column:fuel_type_detail"                       json:"fuel_type_detail"                       form:"fuel_type_detail"`
	FuelLable                           string `gorm:"column:fuel_lable"                             json:"fuel_lable"                             form:"fuel_lable"`
	OilSupplyMode                       string `gorm:"column:oil_supply_mode"                        json:"oil_supply_mode"                        form:"oil_supply_mode"`
	CylinderHeadMaterial                string `gorm:"column:cylinder_head_material"                 json:"cylinder_head_material"                 form:"cylinder_head_material"`
	CylinderMaterial                    string `gorm:"column:cylinder_material"                      json:"cylinder_material"                      form:"cylinder_material"`
	MotorType                           string `gorm:"column:motor_type"                             json:"motor_type"                             form:"motor_type"`
	TotalMotorPower                     string `gorm:"column:total_motor_power"                      json:"total_motor_power"                      form:"total_motor_power"`
	TotalMotorTorque                    string `gorm:"column:total_motor_torque"                     json:"total_motor_torque"                     form:"total_motor_torque"`
	FrontElectricMaximumPower           string `gorm:"column:front_electric_maximum_power"           json:"front_electric_maximum_power"           form:"front_electric_maximum_power"`
	FrontElectricTorque                 string `gorm:"column:front_electric_torque"                  json:"front_electric_torque"                  form:"front_electric_torque"`
	BackElectricMaximumPower            string `gorm:"column:back_electric_maximum_power"            json:"back_electric_maximum_power"            form:"back_electric_maximum_power"`
	BackElectricTorque                  string `gorm:"column:back_electric_torque"                   json:"back_electric_torque"                   form:"back_electric_torque"`
	SystemIntegratedPower               string `gorm:"column:system_integrated_power"                json:"system_integrated_power"                form:"system_integrated_power"`
	SystemIntegratedTorque              string `gorm:"column:system_integrated_torque"               json:"system_integrated_torque"               form:"system_integrated_torque"`
	MotorNumber                         string `gorm:"column:motor_number"                           json:"motor_number"                           form:"motor_number"`
	MotorLayout                         string `gorm:"column:motor_layout"                           json:"motor_layout"                           form:"motor_layout"`
	BatteryType                         string `gorm:"column:battery_type"                           json:"battery_type"                           form:"battery_type"`
	MaximumSimulationMilage             string `gorm:"column:maximum_simulation_milage"              json:"maximum_simulation_milage"              form:"maximum_simulation_milage"`
	BatteryEnergy                       string `gorm:"column:battery_energy"                         json:"battery_energy"                         form:"battery_energy"`
	HundredElectricityConsumption       string `gorm:"column:hundred_electricity_consumption"        json:"hundred_electricity_consumption"        form:"hundred_electricity_consumption"`
	BatteryPackWarranty                 string `gorm:"column:battery_pack_warranty"                  json:"battery_pack_warranty"                  form:"battery_pack_warranty"`
	GearNumber                          string `gorm:"column:gear_number"                            json:"gear_number"                            form:"gear_number"`
	GearboxType                         string `gorm:"column:gearbox_type"                           json:"gearbox_type"                           form:"gearbox_type"`
	DriveType                           string `gorm:"column:drive_type"                             json:"drive_type"                             form:"drive_type"`
	FrontSuspentionType                 string `gorm:"column:front_suspention_type"                  json:"front_suspention_type"                  form:"front_suspention_type"`
	BackSuspentionType                  string `gorm:"column:back_suspention_type"                   json:"back_suspention_type"                   form:"back_suspention_type"`
	AssistType                          string `gorm:"column:assist_type"                            json:"assist_type"                            form:"assist_type"`
	BodyStructure                       string `gorm:"column:body_structure"                         json:"body_structure"                         form:"body_structure"`
	FrontBrakeType                      string `gorm:"column:front_brake_type"                       json:"front_brake_type"                       form:"front_brake_type"`
	BackBrakeType                       string `gorm:"column:back_brake_type"                        json:"back_brake_type"                        form:"back_brake_type"`
	ParkingBrakeType                    string `gorm:"column:parking_brake_type"                     json:"parking_brake_type"                     form:"parking_brake_type"`
	FrontWheelSpecification             string `gorm:"column:front_wheel_specification"              json:"front_wheel_specification"              form:"front_wheel_specification"`
	BackWheelSpecification              string `gorm:"column:back_wheel_specification"               json:"back_wheel_specification"               form:"back_wheel_specification"`
	SpareWheelSpecification             string `gorm:"column:spare_wheel_specification"              json:"spare_wheel_specification"              form:"spare_wheel_specification"`
	MainSeatAirbag                      string `gorm:"column:main_seat_airbag"                       json:"main_seat_airbag"                       form:"main_seat_airbag"`
	AuxiliarySeatAirbag                 string `gorm:"column:auxiliary_seat_airbag"                  json:"auxiliary_seat_airbag"                  form:"auxiliary_seat_airbag"`
	FrontSideAirbag                     string `gorm:"column:front_side_airbag"                      json:"front_side_airbag"                      form:"front_side_airbag"`
	BackSideAirbag                      string `gorm:"column:back_side_airbag"                       json:"back_side_airbag"                       form:"back_side_airbag"`
	FontHeadAirbag                      string `gorm:"column:font_head_airbag"                       json:"font_head_airbag"                       form:"font_head_airbag"`
	BackHeadAirbag                      string `gorm:"column:back_head_airbag"                       json:"back_head_airbag"                       form:"back_head_airbag"`
	KneeAirbag                          string `gorm:"column:knee_airbag"                            json:"knee_airbag"                            form:"knee_airbag"`
	PassengerSeatCushionAirbag          string `gorm:"column:passenger_seat_cushion_airbag"          json:"passenger_seat_cushion_airbag"          form:"passenger_seat_cushion_airbag"`
	FrontMiddleAirbag                   string `gorm:"column:front_middle_airbag"                    json:"front_middle_airbag"                    form:"front_middle_airbag"`
	BackBeltAirbag                      string `gorm:"column:back_belt_airbag"                       json:"back_belt_airbag"                       form:"back_belt_airbag"`
	RearSeatAntiSlideAirbag             string `gorm:"column:rear_seat_anti_slide_airbag"            json:"rear_seat_anti_slide_airbag"            form:"rear_seat_anti_slide_airbag"`
	RearCentralAirbag                   string `gorm:"column:rear_central_airbag"                    json:"rear_central_airbag"                    form:"rear_central_airbag"`
	PassivePedestrianProtection         string `gorm:"column:passive_pedestrian_protection"          json:"passive_pedestrian_protection"          form:"passive_pedestrian_protection"`
	TirePresureMonitor                  string `gorm:"column:tire_presure_monitor"                   json:"tire_presure_monitor"                   form:"tire_presure_monitor"`
	RunFlatTire                         string `gorm:"column:run_flat_tire"                          json:"run_flat_tire"                          form:"run_flat_tire"`
	SeatBeltWarning                     string `gorm:"column:seat_belt_warning"                      json:"seat_belt_warning"                      form:"seat_belt_warning"`
	IsoFix                              string `gorm:"column:iso_fix"                                json:"iso_fix"                                form:"iso_fix"`
	Abs                                 string `gorm:"column:abs"                                    json:"abs"                                    form:"abs"`
	EbdCbc                              string `gorm:"column:ebd_cbc"                                json:"ebd_cbc"                                form:"ebd_cbc"`
	EbaBasBa                            string `gorm:"column:eba_bas_ba"                             json:"eba_bas_ba"                             form:"eba_bas_ba"`
	AsrTcsTrc                           string `gorm:"column:asr_tcs_trc"                            json:"asr_tcs_trc"                            form:"asr_tcs_trc"`
	Esp                                 string `gorm:"column:esp"                                    json:"esp"                                    form:"esp"`
	ParallelAuxiliary                   string `gorm:"column:parallel_auxiliary"                     json:"parallel_auxiliary"                     form:"parallel_auxiliary"`
	LaneDepartureWarningSystem          string `gorm:"column:lane_departure_warning_system"          json:"lane_departure_warning_system"          form:"lane_departure_warning_system"`
	LaneKeeping                         string `gorm:"column:lane_keeping"                           json:"lane_keeping"                           form:"lane_keeping"`
	RoadTrafficSignRecognition          string `gorm:"column:road_traffic_sign_recognition"          json:"road_traffic_sign_recognition"          form:"road_traffic_sign_recognition"`
	ActiveBrake                         string `gorm:"column:active_brake"                           json:"active_brake"                           form:"active_brake"`
	NightVision                         string `gorm:"column:night_vision"                           json:"night_vision"                           form:"night_vision"`
	FatigueDrivingWarning               string `gorm:"column:fatigue_driving_warning"                json:"fatigue_driving_warning"                form:"fatigue_driving_warning"`
	FrontParkingRador                   string `gorm:"column:front_parking_rador"                    json:"front_parking_rador"                    form:"front_parking_rador"`
	BackParkingRador                    string `gorm:"column:back_parking_rador"                     json:"back_parking_rador"                     form:"back_parking_rador"`
	AutomaticDrivingAssistance          string `gorm:"column:automatic_driving_assistance"           json:"automatic_driving_assistance"           form:"automatic_driving_assistance"`
	ReverseVehicleSideWarningSystem     string `gorm:"column:reverse_vehicle_side_warning_system"    json:"reverse_vehicle_side_warning_system"    form:"reverse_vehicle_side_warning_system"`
	CruiseSystem                        string `gorm:"column:cruise_system"                          json:"cruise_system"                          form:"cruise_system"`
	DrivingModeSelection                string `gorm:"column:driving_mode_selection"                 json:"driving_mode_selection"                 form:"driving_mode_selection"`
	AutomaticParking                    string `gorm:"column:automatic_parking"                      json:"automatic_parking"                      form:"automatic_parking"`
	EngineStartStopTechnology           string `gorm:"column:engine_start_stop_technology"           json:"engine_start_stop_technology"           form:"engine_start_stop_technology"`
	AutoHold                            string `gorm:"column:auto_hold"                              json:"auto_hold"                              form:"auto_hold"`
	AscentAssist                        string `gorm:"column:ascent_assist"                          json:"ascent_assist"                          form:"ascent_assist"`
	Hdc                                 string `gorm:"column:hdc"                                    json:"hdc"                                    form:"hdc"`
	VariableSuspension                  string `gorm:"column:variable_suspension"                    json:"variable_suspension"                    form:"variable_suspension"`
	AirSuspension                       string `gorm:"column:air_suspension"                         json:"air_suspension"                         form:"air_suspension"`
	EInductionSuspension                string `gorm:"column:e_induction_suspension"                 json:"e_induction_suspension"                 form:"e_induction_suspension"`
	VariableSteeringRatio               string `gorm:"column:variable_steering_ratio"                json:"variable_steering_ratio"                form:"variable_steering_ratio"`
	CentralDiffLock                     string `gorm:"column:central_diff_lock"                      json:"central_diff_lock"                      form:"central_diff_lock"`
	OverallActiveSteeringSystem         string `gorm:"column:overall_active_steering_system"         json:"overall_active_steering_system"         form:"overall_active_steering_system"`
	Edl                                 string `gorm:"column:edl"                                    json:"edl"                                    form:"edl"`
	WadeSensingSystem                   string `gorm:"column:wade_sensing_system"                    json:"wade_sensing_system"                    form:"wade_sensing_system"`
	SkylightType                        string `gorm:"column:skylight_type"                          json:"skylight_type"                          form:"skylight_type"`
	SportsAppearanceKit                 string `gorm:"column:sports_appearance_kit"                  json:"sports_appearance_kit"                  form:"sports_appearance_kit"`
	Tail                                string `gorm:"column:tail"                                   json:"tail"                                   form:"tail"`
	RimMaterial                         string `gorm:"column:rim_material"                           json:"rim_material"                           form:"rim_material"`
	Eosd                                string `gorm:"column:eosd"                                   json:"eosd"                                   form:"eosd"`
	FramelessDesignDoor                 string `gorm:"column:frameless_design_door"                  json:"frameless_design_door"                  form:"frameless_design_door"`
	SideSlidingDoor                     string `gorm:"column:side_sliding_door"                      json:"side_sliding_door"                      form:"side_sliding_door"`
	ElectricTrunk                       string `gorm:"column:electric_trunk"                         json:"electric_trunk"                         form:"electric_trunk"`
	InductiveTrunk                      string `gorm:"column:inductive_trunk"                        json:"inductive_trunk"                        form:"inductive_trunk"`
	RearCompartmentPositionMemory       string `gorm:"column:rear_compartment_position_memory"       json:"rear_compartment_position_memory"       form:"rear_compartment_position_memory"`
	TheTailgateGlassOpensIndependently  string `gorm:"column:the_tailgate_glass_opens_independently" json:"the_tailgate_glass_opens_independently" form:"the_tailgate_glass_opens_independently"`
	RoofLuggageRack                     string `gorm:"column:roof_luggage_rack"                      json:"roof_luggage_rack"                      form:"roof_luggage_rack"`
	ElectronicAntiTheft                 string `gorm:"column:electronic_anti_theft"                  json:"electronic_anti_theft"                  form:"electronic_anti_theft"`
	CentralControlLock                  string `gorm:"column:central_control_lock"                   json:"central_control_lock"                   form:"central_control_lock"`
	KeyType                             string `gorm:"column:key_type"                               json:"key_type"                               form:"key_type"`
	KeylessStartSystem                  string `gorm:"column:keyless_start_system"                   json:"keyless_start_system"                   form:"keyless_start_system"`
	KeylessEntrySystem                  string `gorm:"column:keyless_entry_system"                   json:"keyless_entry_system"                   form:"keyless_entry_system"`
	HideElectricDoorHandle              string `gorm:"column:hide_electric_door_handle"              json:"hide_electric_door_handle"              form:"hide_electric_door_handle"`
	ActiveIntakeGrille                  string `gorm:"column:active_intake_grille"                   json:"active_intake_grille"                   form:"active_intake_grille"`
	RemoteStart                         string `gorm:"column:remote_start"                           json:"remote_start"                           form:"remote_start"`
	OutsidePedal                        string `gorm:"column:outside_pedal"                          json:"outside_pedal"                          form:"outside_pedal"`
	BatteryPreHeating                   string `gorm:"column:battery_pre_heating"                    json:"battery_pre_heating"                    form:"battery_pre_heating"`
	SteeringWheelMaterial               string `gorm:"column:steering_wheel_material"                json:"steering_wheel_material"                form:"steering_wheel_material"`
	SteeringWheelAdjustment             string `gorm:"column:steering_wheel_adjustment"              json:"steering_wheel_adjustment"              form:"steering_wheel_adjustment"`
	MultiFunctionalSteeringWheel        string `gorm:"column:multi_functional_steering_wheel"        json:"multi_functional_steering_wheel"        form:"multi_functional_steering_wheel"`
	SteeringWheelShift                  string `gorm:"column:steering_wheel_shift"                   json:"steering_wheel_shift"                   form:"steering_wheel_shift"`
	SteeringWheelHeating                string `gorm:"column:steering_wheel_heating"                 json:"steering_wheel_heating"                 form:"steering_wheel_heating"`
	SteeringWheelRemember               string `gorm:"column:steering_wheel_remember"                json:"steering_wheel_remember"                form:"steering_wheel_remember"`
	DrivingComputerDisplay              string `gorm:"column:driving_computer_display"               json:"driving_computer_display"               form:"driving_computer_display"`
	FullLcdDashboard                    string `gorm:"column:full_lcd_dashboard"                     json:"full_lcd_dashboard"                     form:"full_lcd_dashboard"`
	FullLcdDashboardSize                string `gorm:"column:full_lcd_dashboard_size"                json:"full_lcd_dashboard_size"                form:"full_lcd_dashboard_size"`
	HudRisingNumberDisplay              string `gorm:"column:hud_rising_number_display"              json:"hud_rising_number_display"              form:"hud_rising_number_display"`
	CarDrivingRecorder                  string `gorm:"column:car_driving_recorder"                   json:"car_driving_recorder"                   form:"car_driving_recorder"`
	ActiveNoiseReduction                string `gorm:"column:active_noise_reduction"                 json:"active_noise_reduction"                 form:"active_noise_reduction"`
	MobilePhoneWirelessCharging         string `gorm:"column:mobile_phone_wireless_charging"         json:"mobile_phone_wireless_charging"         form:"mobile_phone_wireless_charging"`
	ElectricallyAdjustablePedal         string `gorm:"column:electrically_adjustable_pedal"          json:"electrically_adjustable_pedal"          form:"electrically_adjustable_pedal"`
	SeatMaterial                        string `gorm:"column:seat_material"                          json:"seat_material"                          form:"seat_material"`
	SportSeat                           string `gorm:"column:sport_seat"                             json:"sport_seat"                             form:"sport_seat"`
	MainSeatAdjustmentMode              string `gorm:"column:main_seat_adjustment_mode"              json:"main_seat_adjustment_mode"              form:"main_seat_adjustment_mode"`
	AuxiliarySeatAdjustmentMode         string `gorm:"column:auxiliary_seat_adjustment_mode"         json:"auxiliary_seat_adjustment_mode"         form:"auxiliary_seat_adjustment_mode"`
	MainElectricAdust                   string `gorm:"column:main_electric_adust"                    json:"main_electric_adust"                    form:"main_electric_adust"`
	AuxiliaryElectricAdust              string `gorm:"column:auxiliary_electric_adust"               json:"auxiliary_electric_adust"               form:"auxiliary_electric_adust"`
	FrontSeatFunction                   string `gorm:"column:front_seat_function"                    json:"front_seat_function"                    form:"front_seat_function"`
	ElectricSeatRemeber                 string `gorm:"column:electric_seat_remeber"                  json:"electric_seat_remeber"                  form:"electric_seat_remeber"`
	AuxiliaryAdjustableButton           string `gorm:"column:auxiliary_adjustable_button"            json:"auxiliary_adjustable_button"            form:"auxiliary_adjustable_button"`
	SecondRowSeatAdjustment             string `gorm:"column:second_row_seat_adjustment"             json:"second_row_seat_adjustment"             form:"second_row_seat_adjustment"`
	RearSeatElectricAdjustment          string `gorm:"column:rear_seat_electric_adjustment"          json:"rear_seat_electric_adjustment"          form:"rear_seat_electric_adjustment"`
	RearSeatFunction                    string `gorm:"column:rear_seat_function"                     json:"rear_seat_function"                     form:"rear_seat_function"`
	BackFoldTable                       string `gorm:"column:back_fold_table"                        json:"back_fold_table"                        form:"back_fold_table"`
	SecondIndependent                   string `gorm:"column:second_independent"                     json:"second_independent"                     form:"second_independent"`
	SeatLayoutForm                      string `gorm:"column:seat_layout_form"                       json:"seat_layout_form"                       form:"seat_layout_form"`
	BackDownType                        string `gorm:"column:back_down_type"                         json:"back_down_type"                         form:"back_down_type"`
	RearSeatPowerDown                   string `gorm:"column:rear_seat_power_down"                   json:"rear_seat_power_down"                   form:"rear_seat_power_down"`
	FrontHandrail                       string `gorm:"column:front_handrail"                         json:"front_handrail"                         form:"front_handrail"`
	BackHandrail                        string `gorm:"column:back_handrail"                          json:"back_handrail"                          form:"back_handrail"`
	BackCupHolder                       string `gorm:"column:back_cup_holder"                        json:"back_cup_holder"                        form:"back_cup_holder"`
	HeatingCoolingCupHolder             string `gorm:"column:heating_cooling_cup_holder"             json:"heating_cooling_cup_holder"             form:"heating_cooling_cup_holder"`
	CentralColourScreen                 string `gorm:"column:central_colour_screen"                  json:"central_colour_screen"                  form:"central_colour_screen"`
	CenterConsoleLargeScreenSize        string `gorm:"column:center_console_large_screen_size"       json:"center_console_large_screen_size"       form:"center_console_large_screen_size"`
	Gps                                 string `gorm:"column:gps"                                    json:"gps"                                    form:"gps"`
	NavigationTrafficInformationDisplay string `gorm:"column:navigation_traffic_information_display" json:"navigation_traffic_information_display" form:"navigation_traffic_information_display"`
	RoadRescueCall                      string `gorm:"column:road_rescue_call"                       json:"road_rescue_call"                       form:"road_rescue_call"`
	CentralLcdSplitScreen               string `gorm:"column:central_lcd_split_screen"               json:"central_lcd_split_screen"               form:"central_lcd_split_screen"`
	CarPhone                            string `gorm:"column:car_phone"                              json:"car_phone"                              form:"car_phone"`
	MobileInternet                      string `gorm:"column:mobile_internet"                        json:"mobile_internet"                        form:"mobile_internet"`
	VoiceControl                        string `gorm:"column:voice_control"                          json:"voice_control"                          form:"voice_control"`
	GestureControl                      string `gorm:"column:gesture_control"                        json:"gesture_control"                        form:"gesture_control"`
	FaceRecognition                     string `gorm:"column:face_recognition"                       json:"face_recognition"                       form:"face_recognition"`
	CarInternet                         string `gorm:"column:car_internet"                           json:"car_internet"                           form:"car_internet"`
	Ota                                 string `gorm:"column:ota"                                    json:"ota"                                    form:"ota"`
	CarTv                               string `gorm:"column:car_tv"                                 json:"car_tv"                                 form:"car_tv"`
	BackLcd                             string `gorm:"column:back_lcd"                               json:"back_lcd"                               form:"back_lcd"`
	RearControlMultimedia               string `gorm:"column:rear_control_multimedia"                json:"rear_control_multimedia"                form:"rear_control_multimedia"`
	ChargingInterface                   string `gorm:"column:charging_interface"                     json:"charging_interface"                     form:"charging_interface"`
	NumberOfInterfaces                  string `gorm:"column:number_of_interfaces"                   json:"number_of_interfaces"                   form:"number_of_interfaces"`
	CdDvd                               string `gorm:"column:cd_dvd"                                 json:"cd_dvd"                                 form:"cd_dvd"`
	PowerOf220v                         string `gorm:"column:power_of220v"                           json:"power_of220v"                           form:"power_of220v"`
	InterfaceOf12v                      string `gorm:"column:interface_of12v"                        json:"interface_of12v"                        form:"interface_of12v"`
	SpeakerBrand                        string `gorm:"column:speaker_brand"                          json:"speaker_brand"                          form:"speaker_brand"`
	SpeakerNumber                       string `gorm:"column:speaker_number"                         json:"speaker_number"                         form:"speaker_number"`
	Near                                string `gorm:"column:near"                                   json:"near"                                   form:"near"`
	Far                                 string `gorm:"column:far"                                    json:"far"                                    form:"far"`
	LightingFeatures                    string `gorm:"column:lighting_features"                      json:"lighting_features"                      form:"lighting_features"`
	Daytime                             string `gorm:"column:daytime"                                json:"daytime"                                form:"daytime"`
	AdaptiveFarNear                     string `gorm:"column:adaptive_far_near"                      json:"adaptive_far_near"                      form:"adaptive_far_near"`
	AutoHead                            string `gorm:"column:auto_head"                              json:"auto_head"                              form:"auto_head"`
	SteeringAssistLamp                  string `gorm:"column:steering_assist_lamp"                   json:"steering_assist_lamp"                   form:"steering_assist_lamp"`
	SideTurn                            string `gorm:"column:side_turn"                              json:"side_turn"                              form:"side_turn"`
	Fog                                 string `gorm:"column:fog"                                    json:"fog"                                    form:"fog"`
	HeadlampRainFogMode                 string `gorm:"column:headlamp_rain_fog_mode"                 json:"headlamp_rain_fog_mode"                 form:"headlamp_rain_fog_mode"`
	HeightAdjustable                    string `gorm:"column:height_adjustable"                      json:"height_adjustable"                      form:"height_adjustable"`
	Clean                               string `gorm:"column:clean"                                  json:"clean"                                  form:"clean"`
	HeadlampDelayOff                    string `gorm:"column:headlamp_delay_off"                     json:"headlamp_delay_off"                     form:"headlamp_delay_off"`
	TouchReadingLamp                    string `gorm:"column:touch_reading_lamp"                     json:"touch_reading_lamp"                     form:"touch_reading_lamp"`
	Atmosphere                          string `gorm:"column:atmosphere"                             json:"atmosphere"                             form:"atmosphere"`
	FrontElectricWindow                 string `gorm:"column:front_electric_window"                  json:"front_electric_window"                  form:"front_electric_window"`
	BackElectricWindow                  string `gorm:"column:back_electric_window"                   json:"back_electric_window"                   form:"back_electric_window"`
	WindowOneKey                        string `gorm:"column:window_one_key"                         json:"window_one_key"                         form:"window_one_key"`
	AntiPinchHand                       string `gorm:"column:anti_pinch_hand"                        json:"anti_pinch_hand"                        form:"anti_pinch_hand"`
	MultilayerSoundInsulationGlass      string `gorm:"column:multilayer_sound_insulation_glass"      json:"multilayer_sound_insulation_glass"      form:"multilayer_sound_insulation_glass"`
	ExteriorRearviewMirrorFunction      string `gorm:"column:exterior_rearview_mirror_function"      json:"exterior_rearview_mirror_function"      form:"exterior_rearview_mirror_function"`
	InteriorRearviewMirrorFunction      string `gorm:"column:interior_rearview_mirror_function"      json:"interior_rearview_mirror_function"      form:"interior_rearview_mirror_function"`
	BackSunshade                        string `gorm:"column:back_sunshade"                          json:"back_sunshade"                          form:"back_sunshade"`
	BackSideSunshade                    string `gorm:"column:back_side_sunshade"                     json:"back_side_sunshade"                     form:"back_side_sunshade"`
	BackSidePrivacy                     string `gorm:"column:back_side_privacy"                      json:"back_side_privacy"                      form:"back_side_privacy"`
	Cosmetic                            string `gorm:"column:cosmetic"                               json:"cosmetic"                               form:"cosmetic"`
	BackWiper                           string `gorm:"column:back_wiper"                             json:"back_wiper"                             form:"back_wiper"`
	FrontWiper                          string `gorm:"column:front_wiper"                            json:"front_wiper"                            form:"front_wiper"`
	HeatableSprayNozzle                 string `gorm:"column:heatable_spray_nozzle"                  json:"heatable_spray_nozzle"                  form:"heatable_spray_nozzle"`
	AirconditionControlType             string `gorm:"column:aircondition_control_type"              json:"aircondition_control_type"              form:"aircondition_control_type"`
	RearIndependentAirConditioner       string `gorm:"column:rear_independent_air_conditioner"       json:"rear_independent_air_conditioner"       form:"rear_independent_air_conditioner"`
	RearSeatAirOutlet                   string `gorm:"column:rear_seat_air_outlet"                   json:"rear_seat_air_outlet"                   form:"rear_seat_air_outlet"`
	TemperatureZoneControl              string `gorm:"column:temperature_zone_control"               json:"temperature_zone_control"               form:"temperature_zone_control"`
	CarAirPurifier                      string `gorm:"column:car_air_purifier"                       json:"car_air_purifier"                       form:"car_air_purifier"`
	Pm25Device                          string `gorm:"column:pm25_device"                            json:"pm25_device"                            form:"pm25_device"`
	NegativeIonGenerator                string `gorm:"column:negative_ion_generator"                 json:"negative_ion_generator"                 form:"negative_ion_generator"`
	FragranceSystem                     string `gorm:"column:fragrance_system"                       json:"fragrance_system"                       form:"fragrance_system"`
	Refrigerator                        string `gorm:"column:refrigerator"                           json:"refrigerator"                           form:"refrigerator"`
	AuxiliaryDrivingChip                string `gorm:"column:auxiliary_driving_chip"                 json:"auxiliary_driving_chip"                 form:"auxiliary_driving_chip"`
	ChipComputingPower                  string `gorm:"column:chip_computing_power"                   json:"chip_computing_power"                   form:"chip_computing_power"`
	NumberOfCameras                     string `gorm:"column:number_of_cameras"                      json:"number_of_cameras"                      form:"number_of_cameras"`
	NumberOfUltrasonicRadars            string `gorm:"column:number_of_ultrasonic_radars"            json:"number_of_ultrasonic_radars"            form:"number_of_ultrasonic_radars"`
	NumberOfMillimeterWaveRadars        string `gorm:"column:number_of_millimeter_wave_radars"       json:"number_of_millimeter_wave_radars"       form:"number_of_millimeter_wave_radars"`
	NumberOfLidars                      string `gorm:"column:number_of_lidars"                       json:"number_of_lidars"                       form:"number_of_lidars"`
	BodyColour                          string `gorm:"column:body_colour"                            json:"body_colour"                            form:"body_colour"`
	InteriorColor                       string `gorm:"column:interior_color"                         json:"interior_color"                         form:"interior_color"`
	IsOn                                int64  `gorm:"column:is_on"                                  json:"is_on"                                  form:"is_on"`
	CreatedAt                           int64  `gorm:"column:created_at"                             json:"created_at"                             form:"created_at"`
	UpdatedAt                           int64  `gorm:"column:updated_at"                             json:"updated_at"                             form:"updated_at"`
}

type StyleList struct {
	ID         int64  `gorm:"column:id"          json:"id"          form:"id"`
	BrandId    string `gorm:"column:brand_id"    json:"brand_id"    form:"brand_id"`
	BrandName  string `gorm:"column:brand_name"  json:"brand_name"  form:"brand_name"`
	SeriesId   string `gorm:"column:series_id"   json:"series_id"   form:"series_id"`
	SeriesName string `gorm:"column:series_name" json:"series_name" form:"series_name"`
	StyleId    string `gorm:"column:style_id"    json:"style_id"    form:"style_id"`
	StyleName  string `gorm:"column:style_name"  json:"style_name"  form:"style_name"`
	Maker      string `gorm:"column:maker"       json:"maker"       form:"maker"`
	IsOn       int64  `gorm:"column:is_on"       json:"is_on"       form:"is_on"`
	MaintainId int64  `gorm:"column:maintain_id" json:"maintain_id" form:"maintain_id"`
}

type defalutSyStyleModel struct {
	tableName string
}

func NewSyStyleModel() SyStyleModel {
	return &defalutSyStyleModel{
		tableName: "db_adm_ads.t_adm_ads5",
	}
}

func (d *defalutSyStyleModel) Update(db *gorm.DB, values interface{}) error {
	return database.Update(db, values, database.Option{
		TableName: d.tableName,
	})
}

func (d *defalutSyStyleModel) List(db *gorm.DB, pagination *Pagination, join bool) ([]StyleList, error) {
	var res []StyleList

	option := database.Option{
		TableName: d.tableName + " AS t1",
		Joins:     []string{"LEFT JOIN db_adm_ads.t_adm_ads13 AS t2 ON t1.style_id = t2.style_id"},
		Fields:    "t1.id, brand_name, series_id, series_name, t1.style_id, style_name, maker, is_on, t2.id AS maintain_id",
		Limit:     pagination.Limit,
		OffSet:    pagination.Offset,
	}
	if join {
		option.Joins = []string{}
	}

	err := database.List(db, &res, option)

	return res, err
}

func (d *defalutSyStyleModel) Count(db *gorm.DB, join bool) (int64, error) {
	option := database.Option{}
	if join {
		option = database.Option{
			TableName: d.tableName + " AS t1",
			Joins:     []string{"LEFT JOIN db_adm_ads.t_adm_ads13 AS t2 ON t1.style_id = t2.style_id"},
		}
	} else {
		option = database.Option{
			TableName: d.tableName + " AS t1",
		}
	}
	return database.Count(db, option)
}

func (d *defalutSyStyleModel) Get(db *gorm.DB) (*GdSyStyle, error) {
	var res GdSyStyle
	err := database.Get(db, &res, database.Option{
		TableName: d.tableName,
	})

	return &res, err
}

func (d *defalutSyStyleModel) StyleList(db *gorm.DB, fields string, limit int) ([]GdSyStyle, error) {
	var res []GdSyStyle

	if fields == "" {
		fields = "*"
	}

	err := database.List(db, &res, database.Option{
		TableName: d.tableName,
		Fields:    fields,
		Limit:     limit,
	})

	return res, err
}

func (d *defalutSyStyleModel) StyleListByMap(db *gorm.DB, fields string, limit int) ([]map[string]interface{}, error) {
	var res []map[string]interface{}

	if fields == "" {
		fields = "*"
	}

	err := database.List(db, &res, database.Option{
		TableName: d.tableName,
		Fields:    fields,
		Limit:     limit,
	})

	return res, err
}
